﻿

libname xu 'p:\vsd_method\q0_50_q1_50';


%macro new_sim (sim_start,numsim,Nsubj,studyend,riskwindow,alpha,beta,true_confirm_rate_S0,true_confirm_rate_S1,true_confirm_rate_M0,true_confirm_rate_M1,
true_confirm_rate_L0,true_confirm_rate_L1,chart_review_p_S0,chart_review_p_S1,chart_review_p_M0,chart_review_p_M1,chart_review_p_L0,chart_review_p_L1);
%do ii=&sim_start %to &numsim;

*Step1, simulate cohort with three sites (large, medium and small), with each suject with three interval:risk-window, control-windows before and after risk-window;
data cohort;
 seed=1021231+&ii;

 siteN10=0.1*&Nsubj;
 siteN40=0.4*&Nsubj;  *this will give 10%, 30% and 60% sample size for s, m and l sites;

do id=1 to &Nsubj;

if id=<siteN10 then do;
 site='S';
end;

else if id=<siteN40 then do;
 site='M';
end;

else do;
 site='L';
end;

   vacdays=1+round(&studyend*ranuni(seed));

   if 10=<vacdays =< (360-&riskwindow) then do; **vac between 10-318 days;
   do int=1 to 3; 
	   if int=1 then do;
         start=1; end=vacdays-1; pt=vacdays-1; risk=0;  output;
       end;
	   else if int=2 then do;
         start=vacdays; end=vacdays+&riskwindow-1; pt=&riskwindow; risk=1; output;
	   end;
	   else if int=3 then do;
         start=vacdays+&riskwindow; end=360; pt=end-start+1; risk=0; output;
	   end;
    end;
    end;

end;

run;


*step2: assign true confirmation rate and simulate observed cases using poisson distn with parameter mu=lambda/true confirmation rate-see Xu et al 2014;
data simcase;
 set cohort;

     if site='S' and risk=0 then true_confirm_rate=&true_confirm_rate_S0;
else if site='S' and risk=1 then true_confirm_rate=&true_confirm_rate_S1;

else if site='M' and risk=0 then true_confirm_rate=&true_confirm_rate_M0;
else if site='M' and risk=1 then true_confirm_rate=&true_confirm_rate_M1;

else if site='L' and risk=0 then true_confirm_rate=&true_confirm_rate_M0;
else if site='L' and risk=1 then true_confirm_rate=&true_confirm_rate_M1;

 mu=exp(&alpha+risk*&beta+log(pt))/true_confirm_rate;  **insert comfirmation rate;
 y=ranPOI(seed,mu);
run;


*step3, creat SCCS sample and assign a caseday using uniform distn within an interval (control or risk windows);
data tmpid;
keep id;
 set simcase;
 if y>=1 then output;
run;

proc sort data=simcase;
by id;
proc sort data=tmpid nodupkey;
by id;
run;

data dtname&ii;
 merge tmpid(in=m) simcase;
 by id;
 logpt=log(pt);
 if y>=1 then caseday=start+round((end-start)*(ranuni(seed)));  **Only one case in the end;
 else caseday=.;
 if m=1;
 run;

*step4, 1) assign chart review proporations based on size of sites and exposure status (risk window vs control window)
        2) assign whether a chart reviewed cases was confirmed using true confirmation rate;
data allsites1;
 set dtname&ii;

     if site='S' and risk=0 then chart_review_p=&chart_review_p_S0;
else if site='S' and risk=1 then chart_review_p=&chart_review_p_S1;
else if site='M' and risk=0 then chart_review_p=&chart_review_p_M0;
else if site='M' and risk=1 then chart_review_p=&chart_review_p_M1;
else if site='L' and risk=0 then chart_review_p=&chart_review_p_L0;
else if site='L' and risk=1 then chart_review_p=&chart_review_p_L1;

if y=1 and chart_review_p=1 then chart_reviewed=1;
else if y=1 and chart_review_p<1 then chart_reviewed=ranbin (seed, 1,chart_review_p);

if chart_reviewed=1 then confirmed=ranbin (seed, 1,true_confirm_rate);
run;


*Step 5,creat a dataset with three observations per case: one for control interval before rw, rw, control interval after rw;
proc sort data=allsites1;
by id int;
run;

  data allsites2;
  drop int risk y pt chart_reviewed ;
   array yary[3] y0before y1 y0after;  *y0before for non-risk window before vac, 1 for riskwindow;
   array ptary[3] pt0before pt1 pt0after;

   do i=1 to 3 until(last.id);
    set allsites1;
	by id;
	yary[i]=y;
	ptary[i]=pt;
   end;

   if y1=. and y0after=. then delete;   * a case with only one window does not contribute to likelihood calculation;
run;

*step6, creat a dataset containing chart reviewed cases, then match to the dataset with three observationos per case;
data confirmation;
keep id confirmed;
 set allsites1;
 if y=1;
run;

data confirmation_allsites2;
 merge allsites2 confirmation;
 by id;
 if y1=1 then exposed_status=1;
 else exposed_status=0;

 if confirmed=. then intval=0;       **those not chart reviewed, intval (stands for internal validated)=0;
 else intval=1;                      **those chart reviewed, intval (stands for internal validated)=1 including confirmed and not confirmed;
 
 Lsite=(site='L');
 Msite=(site='M');

 run;

****STATISTICAL MODELS;

*Model 1: obsered cases ---- without correction including all observed cases and ignoring misclassification;
ods trace off;
proc nlmixed data=confirmation_allsites2;
  parm b=0.2;

    if y0after=. then do;
	   mu0before=pt0before/(pt0before+pt1*exp(b)); 
	   mu1=(pt1*exp(b))/(pt0before+pt1*exp(b));
	   c_joint_like=log((mu0before**y0before)*(mu1**y1));
    end;

    else do;
	   mu0before=pt0before/(pt0before+pt1*exp(b)+pt0after); 
	   mu0after=pt0after/(pt0before+pt1*exp(b)+pt0after); 
	   mu1=(pt1*exp(b))/(pt0before+pt1*exp(b)+pt0after);
	   c_joint_like=log((mu0before**y0before)*(mu1**y1)*(mu0after**y0after));
    end;

	model y1~general (c_joint_like);
   ods output ParameterEstimates=observed0;
run;


data observed1;
keep dt Estimate_observed Stderr_observed DF_observed tValue_observed Probt_observed;
 set observed0;
Estimate_observed=Estimate;
Stderr_observed=StandardError;
DF_observed=df;
tValue_observed=tValue;
Probt_observed=Probt;
 dt=&ii;
run;


**Model 2: Confirmed case only ---- just inlcude confirmed case in analysis;
ods trace off;
proc nlmixed data=confirmation_allsites2;
where confirmed=1;
  parm b=0.2;

    if y0after=. then do;
	   mu0before=pt0before/(pt0before+pt1*exp(b)); 
	   mu1=(pt1*exp(b))/(pt0before+pt1*exp(b));
	   c_joint_like=log((mu0before**y0before)*(mu1**y1));
    end;

    else do;
	   mu0before=pt0before/(pt0before+pt1*exp(b)+pt0after); 
	   mu0after=pt0after/(pt0before+pt1*exp(b)+pt0after); 
	   mu1=(pt1*exp(b))/(pt0before+pt1*exp(b)+pt0after);
	   c_joint_like=log((mu0before**y0before)*(mu1**y1)*(mu0after**y0after));
    end;

	model y1~general (c_joint_like);
   ods output ParameterEstimates=confirmedcase0;
run;

data confirmedcase1;
keep dt Estimate_confirmedcase Stderr_confirmedcase DF_confirmedcase tValue_confirmedcase Probt_confirmedcase;
 set confirmedcase0;
Estimate_confirmedcase=Estimate;
Stderr_confirmedcase=StandardError;
DF_confirmedcase=df;
tValue_confirmedcase=tValue;
Probt_confirmedcase=Probt;
 dt=&ii;
run;


*Model 3: constant confirmation rate with exclusion of unconfirmed casese:
estimate confirmation rate and then apply it as known to those not chart reviewed, chart reviewed but not-confirmed cases were excluded;

proc sort data=confirmation_allsites2;
by exposed_status site;
run;

proc freq data=confirmation_allsites2;
 tables confirmed;
by exposed_status site;
ods output OneWayFreqs=cal_confirmation_rate;   **output calculated confirmation rate by site and exposure status;
run;

data cal_confirmation_rate1;
keep exposed_status site cal_confirmation_rate;
 set cal_confirmation_rate;
 if confirmed=1;
cal_confirmation_rate=percent/100;
run;


proc sort data=cal_confirmation_rate1;
by exposed_status site;

proc sort data=confirmation_allsites2;
by exposed_status site;

data cal_confirmation_allsites2;  *merge calculated confirmation rate to those not chart_reviewed;
 merge confirmation_allsites2 cal_confirmation_rate1;
by exposed_status site;
run;

data cal_confirmation_allsites222;
 set cal_confirmation_allsites2;
 if confirmed=0 then delete;**chart reviewed cases and unconfirmed cases were removed !!!!!!!!!!!!!!!!!!!!!!;
run;

proc nlmixed data=cal_confirmation_allsites222;  ***Check this dataset!!!!!!!!!!!!!!!!!!!;
parm b=0.2;
if intval=1 then do;                             **chart reviewed and confirmed cases;
  if y0after=. then do;
	   mu0before=pt0before/(pt0before+pt1*exp(b)); 
	   mu1=(pt1*exp(b))/(pt0before+pt1*exp(b));
	   loglike=log((mu0before**(y0before*confirmed))*(mu1**(y1*confirmed)));
  end;
  else do;
	   mu0before=pt0before/(pt0before+pt1*exp(b)+pt0after); 
	   mu0after=pt0after/(pt0before+pt1*exp(b)+pt0after); 
	   mu1=(pt1*exp(b))/(pt0before+pt1*exp(b)+pt0after);
	   loglike=log((mu0before**(y0before*confirmed))*(mu1**(y1*confirmed))*(mu0after**(y0after*confirmed)));
  end;
end;

else if intval=0 then do;                         *not chart reviewed cases;
  if y0after=. then do;
	   mu0before=pt0before/(pt0before+pt1*exp(b)); 
	   mu1=(pt1*exp(b))/(pt0before+pt1*exp(b));
	   loglike=log((mu0before**(y0before**cal_confirmation_rate))*(mu1**(y1**cal_confirmation_rate)));
  end;
  else do;
	   mu0before=pt0before/(pt0before+pt1*exp(b)+pt0after); 
	   mu0after=pt0after/(pt0before+pt1*exp(b)+pt0after); 
	   mu1=(pt1*exp(b))/(pt0before+pt1*exp(b)+pt0after);
	   loglike=log((mu0before**(y0before*cal_confirmation_rate))*(mu1**(y1*cal_confirmation_rate))*(mu0after**(y0after*cal_confirmation_rate))); **find error here not **;
  end;
end;

	   model y1~general (loglike);
   ods output ParameterEstimates=constant_confirmation0;

run;


data constant_confirmation1;
keep dt Estimate_constant_confirmation Stderr_constant_confirmation DF_constant_confirmation tValue_constant_confirmation Probt_constant_confirmation;
 set constant_confirmation0;
Estimate_constant_confirmation=Estimate;
Stderr_constant_confirmation=StandardError;
DF_constant_confirmation=df;
tValue_constant_confirmation=tValue;
Probt_constant_confirmation=Probt;
 dt=&ii;
run;



*MODEL 4: NEW_PROC NLMIXED WITH correction for confirmation------MI approach;

********************************************;
** MULTIPLE IMPUTATION APPROACH             ;
********************************************;
******************************************************;
** MC MC MC MC approach
*Step 7-MODEL 4: step a): Fit logistic regression model relating confirmed outcome to observed outcome in validation subgroup;


data intvaldt;
 set confirmation_allsites2;
 if intval=1;

 Ssite_exp0=(site='S' & exposed_status=0);
 Ssite_exp1=(site='S' & exposed_status=1);

 Msite_exp0=(site='M' &  exposed_status=0);
 Msite_exp1=(site='M' &  exposed_status=1);

 Lsite_exp0=(site='L' &  exposed_status=0);
 Lsite_exp1=(site='L' &  exposed_status=1);

run;


data Ssite;
 set intvaldt;
 if site='S';
run;

***Do not need impute for small site;
proc logistic data=intvaldt descending covout outest=beta_cov;
model confirmed=Msite_exp0  Msite_exp1 Lsite_exp0 Lsite_exp1/noint;
run;

data beta1; 
set beta_cov; 
if _TYPE_="PARMS"; 

bM0=Msite_exp0; 
bM1=Msite_exp1; 

bL0=Lsite_exp0; 
bL1=Lsite_exp1; 

keep bM0 bM1 bL0 bL1;
run;



data cov; 
keep Msite_exp0  Msite_exp1 Lsite_exp0 Lsite_exp1;
set beta_cov; 
if _TYPE_^="PARMS"; 
run;


*Step 7-MODEL 4: step b): Sample coefficients for each imputation;

proc iml;
use cov; 
read all into cov; *variance-covariance matrix of betas;
use beta1; read all into betas; 
betas=betas`; *estimated betas in to column vector;

*if a combination of site and exposure has no data, cov will be zero, causing proc iml not running;
*fill in the data here, but wonnot impact later modeling;

 do i=1 to 4;
  do j=1 to 4;
   if i=j then do;
    if cov[i,j]=. then cov[i,j]=1;
	else cov[i,j]=cov[i,j];
   end;
   else do;
    if cov[i,j]=. then cov[i,j]=0;
	else cov[i,j]=cov[i,j];
   end;
  end;
  end;

v=nrow(cov); *number of variables;
n=100; *number of imputations;
seed=222;
root_cov=t(root(cov)); *cholesky root of cov matrix;

z=normal(j(v,n,seed)); *generate nvars*samplesize standard normals;
zv=root_cov*z; *multiply standard normals by root cov;

imp_betas_r=repeat(betas,1,n)+zv; *imputed betas in row;

imp_betas_c=t(imp_betas_r);       *put imputed betas in column;

create imp_betas from imp_betas_c; *create sas dataset;
append from imp_betas_c;
quit;

data imp_betas; 
set imp_betas; 
retain _imputation_ 0; 
_imputation_=_imputation_+1;


bM0=col1; 
bM1=col2; 

bL0=col3; 
bL1=col4; 

keep _imputation_ bM0 bM1 bL0 bL1;
run;


 
data foranalysis1; 

set confirmation_allsites2; 
do _imputation_=1 to 100; 
output; 
end;
run;



data beta_orig; 
keep _imputation_ bM0_orig bM1_orig bL0_orig bL1_orig;
 set beta1; 

bM0_orig=bM0; 
bM1_orig=bM1; 
bL0_orig=bL0; 
bL1_orig=bL1;

do _imputation_=1 to 100; 
output; 
end;
run;

proc sort data=beta_orig;
by _imputation_;
proc sort data=imp_betas; 
by _imputation_;
proc sort data=foranalysis1; 
by _imputation_;


*Step 7-MODEL 4: step c): impute outcome for records not in the validation subgroup;
data foranalysis2; 
merge foranalysis1 imp_betas beta_orig; 
by _imputation_; 

run;


data foranalysis3;
 set foranalysis2;
call streaminit(9);

if bM0_orig>13.2 then bM0=13.2;
if bM1_orig>13.2 then bM1=13.2;
if bL0_orig>13.2 then bL0=13.2;
if bL1_orig>13.2 then bL1=13.2;


if bM0_orig<-13.2 then bM0=-13.2;
if bM1_orig<-13.2 then bM1=-13.2;
if bL0_orig<-13.2 then bL0=-13.2;
if bL1_orig<-13.2 then bL1=-13.2;

if confirmed=. then do;

  if site='M' and  exposed_status=0 then xb=bM0;
  else if site='M' and  exposed_status=1 then xb=bM1;
  else if site='L' and  exposed_status=0 then xb=bL0;
  else if site='L' and  exposed_status=1 then xb=bL1;

  **take care of zero cell problem, no need to impute;   
  if xb>13.2 then confirmed_imp=1;
  else if xb<-13.2 then confirmed_imp=0;
  else confirmed_imp=rand("bernoulli",1/(1+exp(-(xb)))); 

end;

else confirmed_imp=confirmed;
run;

data sim_confirmed;
 set foranalysis3;
 if confirmed_imp=1;  **************ONLY ANALYZED THOSE TRUELY CONFIRMED AND SIMULATEDLY CONFIRMED!!!!!!!!!!!!!!!!!!!!;
run;

*Step 7-MODEL 4: step d): Fit conditional Poisson  model in each imputation; 


proc sort data=sim_confirmed;
key _imputation_ / ascending;
run;


ods trace off;
proc nlmixed data=sim_confirmed;
  parm b=0.2;

    if y0after=. then do;
	   mu0before=pt0before/(pt0before+pt1*exp(b)); 
	   mu1=(pt1*exp(b))/(pt0before+pt1*exp(b));
	   c_joint_like=log((mu0before**y0before)*(mu1**y1));
    end;

    else do;
	   mu0before=pt0before/(pt0before+pt1*exp(b)+pt0after); 
	   mu0after=pt0after/(pt0before+pt1*exp(b)+pt0after); 
	   mu1=(pt1*exp(b))/(pt0before+pt1*exp(b)+pt0after);
	   c_joint_like=log((mu0before**y0before)*(mu1**y1)*(mu0after**y0after));
    end;

	model y1~general (c_joint_like);
   ods output ParameterEstimates=MI_results;
   by _imputation_;
run;

proc mianalyze data=MI_results;
modeleffects estimate;
stderr Standarderror;
ods output parameterestimates=MI0;
run;



data MI1;
keep dt Estimate_MI Stderr_MI DF_MI tValue_MI Probt_MI;
 set MI0;
Estimate_MI=Estimate;
Stderr_MI=StdErr;
DF_MI=df;
tValue_MI=tValue;
Probt_MI=Probt;
 dt=&ii;
run;

proc sort data=observed1;
by dt;

proc sort data=confirmedcase1;
by dt;


proc sort data=constant_confirmation1;
by dt;


proc sort data=MI1;;
by dt;


*Step 8: put results from the five approaches into one dataset;
data all_results;
 merge observed1 confirmedcase1 constant_confirmation1 MI1;
 by dt;
run;

*DM log 'clear';
proc append base=xu.a_n12_beta_069_M0_08L0_08 new=all_results force;run;  ***need change!!!!!!;
*DM output 'clear';
%end;
%mend new_sim;


data xu.a_n12_beta_069_M_08L_08;                                                            
input dt Estimate_observed Stderr_observed DF_observed tValue_observed Probt_observed Estimate_confirmedcase Stderr_confirmedcase DF_confirmedcase tValue_confirmedcase Probt_confirmedcase
Estimate_constant_confirmation Stderr_constant_confirmation DF_constant_confirmation tValue_constant_confirmation Probt_constant_confirmation
Estimate_MI Stderr_MI DF_MI tValue_MI Probt_MI;
cards;


%new_sim(sim_start=1,numsim=1000,Nsubj=100000, studyend=360, riskwindow=42, alpha=-12, beta=0.693, true_confirm_rate_S0=0.5,true_confirm_rate_S1=0.5,true_confirm_rate_M0=0.5,true_confirm_rate_M1=0.5,true_confirm_rate_L0=0.5,true_confirm_rate_L1=0.5,chart_review_p_S0=1,chart_review_p_S1=1,chart_review_p_M0=0.8,chart_review_p_M1=0.8,chart_review_p_L0=0.8,chart_review_p_L1=0.8);
run;


option nocenter;
proc means data= xu.a_n12_beta_069_M_08L_08;
 var Estimate_observed Estimate_confirmedcase Estimate_constant_confirmation Estimate_MI;
run;
/*Table 3 mean and MC error

Variable                             N            Mean         Std Dev         Minimum         Maximum
------------------------------------------------------------------------------------------------------
Estimate_observed                 1000       0.6938080       0.1133612       0.3223110       1.0324536
Estimate_confirmedcase            1000       0.6873451       0.1812651       0.0488398       1.3052591
Estimate_constant_confirmation    1000       0.6875612       0.1722705    -0.000084633       1.1983196
Estimate_MI                       1000       0.6857515       0.1720934       0.0265196       1.2031287
-----------------------------------------------------------------------------------------------------
*/

proc means data= xu.a_n12_beta_069_M_08L_08;
 var stderr_observed stderr_confirmedcase Stderr_constant_confirmation stderr_MI;
run;
/* Table 3 mean standard error
Variable                           N            Mean         Std Dev         Minimum         Maximum
----------------------------------------------------------------------------------------------------
Stderr_observed                 1000       0.1196273       0.0048783       0.1074474       0.1355676
Stderr_confirmedcase            1000       0.1882038       0.0124885       0.1557408       0.2448075
Stderr_constant_confirmation    1000       0.1700750       0.0107757       0.1432486       0.2245130
Stderr_MI                       1000       0.1798051       0.0122497       0.1490159       0.2385734
---------------------------------------------------------------------------------------------------
*/


data power;
 set xu.a_n12_beta_069_M_08L_08;

if Probt_observed <0.05 then reject_observed=1;
else reject_observed=0;

if Probt_confirmedcase<0.05 then reject_confirmedcase=1;
else reject_confirmedcase=0;

if Probt_constant_confirmation<0.05 then reject_constant_confirmation=1;
else reject_constant_confirmation=0;

if Probt_MI<0.05 then reject_MI=1;
else reject_MI=0;
run;


proc freq data=power;
 tables reject_observed reject_confirmedcase reject_constant_confirmation reject_MI;
run;
/*Table 5 empirical power

                                                     Cumulative    Cumulative
           reject_observed    Frequency     Percent     Frequency      Percent
           --------------------------------------------------------------------
                         1        1000      100.00          1000       100.00


                    reject_                             Cumulative    Cumulative
              confirmedcase    Frequency     Percent     Frequency      Percent
           ---------------------------------------------------------------------
                          0          63        6.30            63         6.30
                          1         937       93.70          1000       100.00


           reject_constant_                             Cumulative    Cumulative
               confirmation    Frequency     Percent     Frequency      Percent
           ---------------------------------------------------------------------
                          0          36        3.60            36         3.60
                          1         964       96.40          1000       100.00


                                                    Cumulative    Cumulative
              reject_MI    Frequency     Percent     Frequency      Percent
              --------------------------------------------------------------
                      0          45        4.50            45         4.50
                      1         955       95.50          1000       100.00
*/


data xu.a_n12_beta_069_M_05L_05;                                       ***need change!!!!!!;                              
input dt Estimate_observed Stderr_observed DF_observed tValue_observed Probt_observed Estimate_confirmedcase Stderr_confirmedcase DF_confirmedcase tValue_confirmedcase Probt_confirmedcase
Estimate_constant_confirmation Stderr_constant_confirmation DF_constant_confirmation tValue_constant_confirmation Probt_constant_confirmation
Estimate_MI Stderr_MI DF_MI tValue_MI Probt_MI;
cards;


%new_sim(sim_start=1,numsim=1000,Nsubj=100000, studyend=360, riskwindow=42, alpha=-12, beta=0.693, true_confirm_rate_S0=0.5,true_confirm_rate_S1=0.5,true_confirm_rate_M0=0.5,true_confirm_rate_M1=0.5,true_confirm_rate_L0=0.5,true_confirm_rate_L1=0.5,chart_review_p_S0=1,chart_review_p_S1=1,chart_review_p_M0=0.5,chart_review_p_M1=0.5,chart_review_p_L0=0.5,chart_review_p_L1=0.5);
run;

option nocenter;
proc means data= xu.a_n12_beta_069_M_05L_05;
 var Estimate_observed Estimate_confirmedcase Estimate_constant_confirmation Estimate_MI;
run;

/*Table 3 mean and MC error
Variable                             N            Mean         Std Dev         Minimum         Maximum
------------------------------------------------------------------------------------------------------
Estimate_observed                 1000       0.6938080       0.1133612       0.3223110       1.0324536
Estimate_confirmedcase            1000       0.6973768       0.2360617      -0.1897924       1.5192868
Estimate_constant_confirmation    1000       0.6917596       0.2038304       0.0456825       1.2925385
Estimate_MI                       1000       0.6859714       0.1992432      -0.0301337       1.2761357
-----------------------------------------------------------------------------------------------------
*/

proc means data= xu.a_n12_beta_069_M_05L_05;
 var stderr_observed stderr_confirmedcase Stderr_constant_confirmation stderr_MI;
run;

/*Table 3 mean standard error
Variable                           N            Mean         Std Dev         Minimum         Maximum
----------------------------------------------------------------------------------------------------
Stderr_observed                 1000       0.1196273       0.0048783       0.1074474       0.1355676
Stderr_confirmedcase            1000       0.2297750       0.0191110       0.1865659       0.3045768
Stderr_constant_confirmation    1000       0.1701369       0.0123595       0.1431938       0.2137241
Stderr_MI                       1000       0.2025553       0.0189537       0.1620976       0.2923350
--------------------------------------------------------------------------------------------------
*/


data power;
 set xu.a_n12_beta_069_M_05L_05;

if Probt_observed <0.05 then reject_observed=1;
else reject_observed=0;

if Probt_confirmedcase<0.05 then reject_confirmedcase=1;
else reject_confirmedcase=0;

if Probt_constant_confirmation<0.05 then reject_constant_confirmation=1;
else reject_constant_confirmation=0;

if Probt_MI<0.05 then reject_MI=1;
else reject_MI=0;
run;


proc freq data=power;
 tables reject_observed reject_confirmedcase reject_constant_confirmation reject_MI;
run;

/*Table 5 empirical power
                                                     Cumulative    Cumulative
           reject_observed    Frequency     Percent     Frequency      Percent
           --------------------------------------------------------------------
                         1        1000      100.00          1000       100.00


                    reject_                             Cumulative    Cumulative
              confirmedcase    Frequency     Percent     Frequency      Percent
           ---------------------------------------------------------------------
                          0         186       18.60           186        18.60
                          1         814       81.40          1000       100.00


           reject_constant_                             Cumulative    Cumulative
               confirmation    Frequency     Percent     Frequency      Percent
           ---------------------------------------------------------------------
                          0          60        6.00            60         6.00
                          1         940       94.00          1000       100.00


                                                    Cumulative    Cumulative
              reject_MI    Frequency     Percent     Frequency      Percent
              --------------------------------------------------------------
                      0         109       10.90           109        10.90
                      1         891       89.10          1000       100.00
*/


data xu.a_n12_beta_069_M0_08L0_08;                                       ***need change!!!!!!;                              
input dt Estimate_observed Stderr_observed DF_observed tValue_observed Probt_observed Estimate_confirmedcase Stderr_confirmedcase DF_confirmedcase tValue_confirmedcase Probt_confirmedcase
Estimate_constant_confirmation Stderr_constant_confirmation DF_constant_confirmation tValue_constant_confirmation Probt_constant_confirmation
Estimate_MI Stderr_MI DF_MI tValue_MI Probt_MI;
cards;


%new_sim(sim_start=1,numsim=1000,Nsubj=100000, studyend=360, riskwindow=42, alpha=-12, beta=0.693, true_confirm_rate_S0=0.5,true_confirm_rate_S1=0.5,true_confirm_rate_M0=0.5,true_confirm_rate_M1=0.5,true_confirm_rate_L0=0.5,true_confirm_rate_L1=0.5,chart_review_p_S0=1,chart_review_p_S1=1,chart_review_p_M0=0.8,chart_review_p_M1=1.0,chart_review_p_L0=0.8,chart_review_p_L1=1.0);
run;


option nocenter;
proc means data= xu.a_n12_beta_069_M0_08L0_08;
 var Estimate_observed Estimate_confirmedcase Estimate_constant_confirmation Estimate_MI;
run;
/*Table 3 mean and MC error
Variable                             N            Mean         Std Dev         Minimum         Maximum
------------------------------------------------------------------------------------------------------
Estimate_observed                 1000       0.6932554       0.1134516       0.3223110       1.0324536
Estimate_confirmedcase            1000       0.8889959       0.1647000       0.3196337       1.4451788
Estimate_constant_confirmation    1000       0.6879086       0.1627778       0.1253411       1.2512073
Estimate_MI                       1000       0.6905525       0.1627953       0.1301415       1.2537260
-----------------------------------------------------------------------------------------------------
*/



proc means data= xu.a_n12_beta_069_M0_08L0_08;
 var stderr_observed stderr_confirmedcase Stderr_constant_confirmation stderr_MI;
run;

/*Table 3 mean standard error
Variable                           N            Mean         Std Dev         Minimum         Maximum
----------------------------------------------------------------------------------------------------
Stderr_observed                 1000       0.1196626       0.0048998       0.1074474       0.1355676
Stderr_confirmedcase            1000       0.1738882       0.0097262       0.1497558       0.2176070
Stderr_constant_confirmation    1000       0.1698473       0.0098451       0.1453651       0.2103206
Stderr_MI                       1000       0.1719439       0.0098123       0.1476915       0.2164939
----------------------------------------------------------------------------------------------------
*/

data power;
 set xu.a_n12_beta_069_M0_08L0_08;

if Probt_observed <0.05 then reject_observed=1;
else reject_observed=0;

if Probt_confirmedcase<0.05 then reject_confirmedcase=1;
else reject_confirmedcase=0;

if Probt_constant_confirmation<0.05 then reject_constant_confirmation=1;
else reject_constant_confirmation=0;

if Probt_MI<0.05 then reject_MI=1;
else reject_MI=0;
run;


proc freq data=power;
 tables reject_observed reject_confirmedcase reject_constant_confirmation reject_MI;
run;

/*Table 5 empirical power
                                                       Cumulative    Cumulative
           reject_observed    Frequency     Percent     Frequency      Percent
           --------------------------------------------------------------------
                         1        1092      100.00          1092       100.00


                    reject_                             Cumulative    Cumulative
              confirmedcase    Frequency     Percent     Frequency      Percent
           ---------------------------------------------------------------------
                          0           3        0.27             3         0.27
                          1        1089       99.73          1092       100.00


           reject_constant_                             Cumulative    Cumulative
               confirmation    Frequency     Percent     Frequency      Percent
           ---------------------------------------------------------------------
                          0          29        2.66            29         2.66
                          1        1063       97.34          1092       100.00


                                                    Cumulative    Cumulative
              reject_MI    Frequency     Percent     Frequency      Percent
              --------------------------------------------------------------
                      0          33        3.03            33         3.03
                      1        1059       96.97          1092       100.00
*/


data xu.a_n12_beta_069_M0_05L0_05;                                       ***need change!!!!!!;                              
input dt Estimate_observed Stderr_observed DF_observed tValue_observed Probt_observed Estimate_confirmedcase Stderr_confirmedcase DF_confirmedcase tValue_confirmedcase Probt_confirmedcase
Estimate_constant_confirmation Stderr_constant_confirmation DF_constant_confirmation tValue_constant_confirmation Probt_constant_confirmation
Estimate_MI Stderr_MI DF_MI tValue_MI Probt_MI;
cards;


%new_sim(sim_start=1,numsim=1000,Nsubj=100000, studyend=360, riskwindow=42, alpha=-12, beta=0.693, true_confirm_rate_S0=0.5,true_confirm_rate_S1=0.5,true_confirm_rate_M0=0.5,true_confirm_rate_M1=0.5,true_confirm_rate_L0=0.5,true_confirm_rate_L1=0.5,chart_review_p_S0=1,chart_review_p_S1=1,chart_review_p_M0=0.5,chart_review_p_M1=1.0,chart_review_p_L0=0.5,chart_review_p_L1=1.0);
run;


option nocenter;
proc means data= xu.a_n12_beta_069_M0_05L0_05;
 var Estimate_observed Estimate_confirmedcase Estimate_constant_confirmation Estimate_MI;
run;

/*Table 3 mean and MC error
Variable                             N            Mean         Std Dev         Minimum         Maximum
------------------------------------------------------------------------------------------------------
Estimate_observed                 1000       0.6935358       0.1135261       0.3223110       1.0324536
Estimate_confirmedcase            1000       1.2816070       0.1753556       0.7050981       1.8363295
Estimate_constant_confirmation    1000       0.6843824       0.1703975       0.1349125       1.2268968
Estimate_MI                       1000       0.6864275       0.1700990       0.1455950       1.2178406
------------------------------------------------------------------------------------------------------
*/

proc means data= xu.a_n12_beta_069_M0_05L0_05;
 var stderr_observed stderr_confirmedcase Stderr_constant_confirmation stderr_MI;
run;

/*Table 3 mean standard error
Variable                           N            Mean         Std Dev         Minimum         Maximum
----------------------------------------------------------------------------------------------------
Stderr_observed                 1000       0.1196428       0.0048913       0.1074474       0.1355676
Stderr_confirmedcase            1000       0.1842432       0.0095678       0.1588077       0.2202979
Stderr_constant_confirmation    1000       0.1701037       0.0098806       0.1466910       0.2068926
Stderr_MI                       1000       0.1778792       0.0098446       0.1532882       0.2134015
----------------------------------------------------------------------------------------------------
*/


data power;
 set xu.a_n12_beta_069_M0_05L0_05;

if Probt_observed <0.05 then reject_observed=1;
else reject_observed=0;

if Probt_confirmedcase<0.05 then reject_confirmedcase=1;
else reject_confirmedcase=0;

if Probt_constant_confirmation<0.05 then reject_constant_confirmation=1;
else reject_constant_confirmation=0;

if Probt_MI<0.05 then reject_MI=1;
else reject_MI=0;
run;


proc freq data=power;
 tables reject_observed reject_confirmedcase reject_constant_confirmation reject_MI;
run;

/*Table 5 empirical power
                                                       Cumulative    Cumulative
           reject_observed    Frequency     Percent     Frequency      Percent
           --------------------------------------------------------------------
                         1        1000      100.00          1000       100.00


                    reject_                             Cumulative    Cumulative
              confirmedcase    Frequency     Percent     Frequency      Percent
           ---------------------------------------------------------------------
                          1        1000      100.00          1000       100.00


           reject_constant_                             Cumulative    Cumulative
               confirmation    Frequency     Percent     Frequency      Percent
           ---------------------------------------------------------------------
                          0          31        3.10            31         3.10
                          1         969       96.90          1000       100.00


                                                    Cumulative    Cumulative
              reject_MI    Frequency     Percent     Frequency      Percent
              --------------------------------------------------------------
                      0          37        3.70            37         3.70
                      1         963       96.30          1000       100.00
*/







































